@@ -307,16 +307,22 @@ class AbacusStru:
     def globalidx2labelidx(self, idx):
         """Get the label and index of the atom in that label from the global index
         """
+        if idx < 0:
+            raise ValueError(f"The idx {idx} is less than 0!")
+        elif idx >= self.get_natoms():
+            raise ValueError(f"The idx {idx} is larger than the total atom numbers!")
+        pre_atom_num = 0
         for i in range(len(self._atom_number)):
-            pre_atom_num = sum(self._atom_number[:i])
-            if idx >= pre_atom_num:
+            kind_i_num = self._atom_number[i]
+            if idx < pre_atom_num + kind_i_num:
                 return self._label[i], idx - pre_atom_num
-        raise ValueError(f"The idx {idx} is larger than the total atom numbers!")
+            pre_atom_num += kind_i_num
     
     def labelidx2globalidx(self, label, idx):
         # Get the global index of the atom from the label and index of that label
         assert (label in self._label), f"{label} is not valid, should be one of {self._label}"
         label_idx = self._label.index(label)
+        assert (idx <= self._atom_number[label_idx]), f"{idx} is larger than the atom number of {label}"
         if label_idx == 0:
             return idx
         else:
@@ -378,6 +384,41 @@ class AbacusStru:
         self.angle1 = None
         self.angle2 = None
     
+    def set_atommag_from_mulliken(self, mullikenf, 
+                                  step=-1,
+                                  check_label=True):
+        '''set the magmom of each atom from mulliken population analysis file
+        step: the step index to read, default is -1, which means the last step
+        check_label: if check the label of mulliken file and stru file
+        Will set angle1 and angle2 to None
+        '''
+        from abacustest.lib_collectdata.comm import get_mulliken
+        try:
+            atom_mag,atom_elec,atom_label = get_mulliken(mullikenf)
+        except Exception as e:
+            traceback.print_exc()
+            print(f"ERROR: read mulliken file {mullikenf} failed.")
+            raise e
+        
+        if len(atom_mag) == 0:
+            print(f"ERROR: no mulliken magmom data in file {mullikenf}.")
+            raise RuntimeError(f"no mulliken magmom data in file {mullikenf}.")
+
+        atom_mag = atom_mag[step]
+        atom_label = atom_label[step]
+        
+        if len(atom_mag) != len(self._coord):
+            print("ERROR: the atom number in mulliken file is not equal to coord number")
+            sys.exit(1)
+        
+        if check_label and atom_label != self.get_label(total=True):
+            print("ERROR: the atom label in mulliken file is not equal to coord label")
+            sys.exit(1)
+        
+        self._magmom_atom = atom_mag
+        self.angle1 = None
+        self.angle2 = None
+    
     def set_angle1(self,new_angle1):
         if new_angle1 is None:
             self._angle1 = None
@@ -1119,7 +1160,23 @@ class AbacusStru:
             
         
      
-    def write(self,struf="STRU"):
+    def write(self,struf="STRU", direct=None):
+        '''
+        write to STRU file
+        direct: if True, then write the coord in direct type, if False, then write in cartesian type
+                if None, then write in the original type
+        '''
+        if direct is None:
+            if self._cartesian:
+                direct = False
+            else:
+                direct = True
+        
+        if direct:
+            coord = self.get_coord(direct=True)
+        else:
+            coord = np.array(self.get_coord(direct=False, bohr = True)) / self._lattice_constant
+
         cc = ""
         #write species
         cc += "ATOMIC_SPECIES\n"
@@ -1151,7 +1208,8 @@ class AbacusStru:
         
         #write ATOMIC_POSITIONS
         cc += "\nATOMIC_POSITIONS\n"
-        if self._cartesian:
+
+        if not direct:
             cc += "Cartesian\n"
         else:
             cc += "Direct\n"
@@ -1159,7 +1217,7 @@ class AbacusStru:
         for i,ilabel in enumerate(self._label):
             cc += "\n%s\n%f\n%d\n" % (ilabel,self._magmom[i],self._atom_number[i])
             for j in range(self._atom_number[i]):
-                cc += "%17.11f %17.11f %17.11f " % tuple(self._coord[icoord + j])
+                cc += "%17.11f %17.11f %17.11f " % tuple(coord[icoord + j])
                 if self._move and self._move[icoord + j] and len(self._move[icoord + j]) == 3:
                     cc += "%d %d %d " % tuple(self._move[icoord + j])
                 if self._magmom_atom:
@@ -1635,7 +1693,7 @@ def ReadKpt(kptpath):
                 print("Have set gamma_only in INPUT file, will use 1 1 1 for KPOINT.")
                 return [1,1,1,0,0,0],"gamma"
             elif kspacing != None and kspacing != 0:
-                print(f"Have set kspacing in INPUT file, kspacing: {kspacing}. Will transfer to KPOINT.")
+                print(f"Have set kspacing in INPUT file, kspacing: {kspacing}. Will transfer to K points.")
                 if not os.path.isfile(struf):
                     print("  Can not find the STRU file, and try to read KPOINT from KPT file")
                     if os.path.isfile(kptf):
@@ -1650,7 +1708,7 @@ def ReadKpt(kptpath):
                         sys.exit(1)
                     cell = stru.get_cell(bohr=True)
                     kpt = comm.kspacing2kpt(kspacing,cell) + [0,0,0]
-                    return kpt,"mp"
+                    return kpt,"gamma"
             elif os.path.isfile(kptf):
                 return ReadKpt(kptf)
             else:
@@ -1664,8 +1722,10 @@ def ReadKpt(kptpath):
     elif os.path.isfile(kptpath):
         with open(kptpath) as f1: lines = [i for i in f1.readlines() if i.split("#")[0].strip() != ""]
         model = lines[2].split()[0].lower()
-        if model.startswith("g") or model.startswith("m"):
+        if model.startswith("m"):
             model = "mp"
+        elif model.startswith("g"):
+            model = "gamma"
         elif model.startswith("d"):
             model = "direct"
         elif model.startswith("c"):
@@ -1741,8 +1801,9 @@ def WriteKpt(kpoint_list:List = [1,1,1,0,0,0],file_name:str = "KPT", model="gamm
     [[0.0,0.0,0.0,10 "#Gamma"],[0.5,0.0,0.0,1,"//"],[0.5,0.5,0.0,1,"//"]]         
     '''
     if model.lower() in ["gamma","mp"]:
+        model_ = "Gamma" if model.lower() == "gamma" else "MP"
         with open(file_name,'w') as f1:
-            f1.write(F"K_POINTS\n0\n{model.capitalize()}\n")
+            f1.write(F"K_POINTS\n0\n{model_}\n")
             if len(kpoint_list) == 3:
                 kpoint_list += [0,0,0]
             f1.write(" ".join([str(i) for i in kpoint_list]))
